@@ -1,6 +1,6 @@
 import importlib
 
-Decorators = importlib.import_module(name="Decorators", package=".Decorators.pyd")
+Decorators = importlib.import_module(name="Decorators", package=".Decorators.py")
 
 CountMainFuncs = importlib.import_module(name="CountMainFuncs", package=".CountMainFuncs.pyd")
 
